Point

Struct Point 

pub struct Point;
A zero-sized namespace providing functionality for elliptic curve point operations for annihilative keys.

Implementations

Source

impl Point

pub fn shared_base(key: &Solution, antikey: &Solution) -> EdwardsPoint

Derive a shared base curve point between two solutions.

Converts each solution to a Scalar and multiplies against the ED25519_BASEPOINT_TABLE to produce two curve points, returning their sum.

pub fn recover_base(key: &AnnihlKey) -> EdwardsPoint

Recover the base curve point of an AnnihlKey.

Using the key’s solution, subtracts a commitment-derived offset from the key’s point to recover the base curve point.

pub fn verify_pair( key: &AnnihlKey, antikey: &AnnihlKey, ) -> Result<(), AnnihlErr>

Verify that an annihilative pair share the same base curve point.

For both member of the pair, base curve points are recovered using each member’s solution, subtracting a commitment-derived offset from the member’s point to recover the base point. Both recovered points are compared to check for a match.

Returns an error if the base curve points for each member of the pair do not match.

pub fn from_u64(val: u64) -> EdwardsPoint

Derive a curve point by constructing a Scalar from a u64 value, then multiplying it against the ED25519_BASEPOINT_TABLE.